==> zio-aws-securityhub_2.13-5.17.163.1-sources.jar: zio/aws/securityhub/model/AwsAutoScalingAutoScalingGroupDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.{Integer, NonEmptyString}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AwsAutoScalingAutoScalingGroupDetails(
    launchConfigurationName: Optional[NonEmptyString] = Optional.Absent,
    loadBalancerNames: Optional[Iterable[NonEmptyString]] = Optional.Absent,
    healthCheckType: Optional[NonEmptyString] = Optional.Absent,
    healthCheckGracePeriod: Optional[Integer] = Optional.Absent,
    createdTime: Optional[NonEmptyString] = Optional.Absent,
    mixedInstancesPolicy: Optional[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails
    ] = Optional.Absent,
    availabilityZones: Optional[Iterable[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails
    ]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsAutoScalingAutoScalingGroupDetails = {
    import AwsAutoScalingAutoScalingGroupDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsAutoScalingAutoScalingGroupDetails
      .builder()
      .optionallyWith(
        launchConfigurationName.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.launchConfigurationName)
      .optionallyWith(
        loadBalancerNames.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.loadBalancerNames)
      .optionallyWith(
        healthCheckType.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.healthCheckType)
      .optionallyWith(
        healthCheckGracePeriod.map(value => value: java.lang.Integer)
      )(_.healthCheckGracePeriod)
      .optionallyWith(
        createdTime.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.createdTime)
      .optionallyWith(mixedInstancesPolicy.map(value => value.buildAwsValue()))(
        _.mixedInstancesPolicy
      )
      .optionallyWith(
        availabilityZones.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.availabilityZones)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupDetails.ReadOnly =
    zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupDetails
      .wrap(buildAwsValue())
}
object AwsAutoScalingAutoScalingGroupDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsAutoScalingAutoScalingGroupDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupDetails =
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupDetails(
        launchConfigurationName.map(value => value),
        loadBalancerNames.map(value => value),
        healthCheckType.map(value => value),
        healthCheckGracePeriod.map(value => value),
        createdTime.map(value => value),
        mixedInstancesPolicy.map(value => value.asEditable),
        availabilityZones.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def launchConfigurationName: Optional[NonEmptyString]
    def loadBalancerNames: Optional[List[NonEmptyString]]
    def healthCheckType: Optional[NonEmptyString]
    def healthCheckGracePeriod: Optional[Integer]
    def createdTime: Optional[NonEmptyString]
    def mixedInstancesPolicy: Optional[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails.ReadOnly
    ]
    def availabilityZones: Optional[List[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails.ReadOnly
    ]]
    def getLaunchConfigurationName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField(
        "launchConfigurationName",
        launchConfigurationName
      )
    def getLoadBalancerNames: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("loadBalancerNames", loadBalancerNames)
    def getHealthCheckType: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("healthCheckType", healthCheckType)
    def getHealthCheckGracePeriod: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("healthCheckGracePeriod", healthCheckGracePeriod)
    def getCreatedTime: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("createdTime", createdTime)
    def getMixedInstancesPolicy: ZIO[
      Any,
      AwsError,
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails.ReadOnly
    ] = AwsError.unwrapOptionField("mixedInstancesPolicy", mixedInstancesPolicy)
    def getAvailabilityZones: ZIO[Any, AwsError, List[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails.ReadOnly
    ]] = AwsError.unwrapOptionField("availabilityZones", availabilityZones)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsAutoScalingAutoScalingGroupDetails
  ) extends zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupDetails.ReadOnly {
    override val launchConfigurationName: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.launchConfigurationName())
        .map(value =>
          zio.aws.securityhub.model.primitives.NonEmptyString(value)
        )
    override val loadBalancerNames: Optional[List[NonEmptyString]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.loadBalancerNames())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.securityhub.model.primitives.NonEmptyString(item)
          }.toList
        )
    override val healthCheckType: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.healthCheckType())
        .map(value =>
          zio.aws.securityhub.model.primitives.NonEmptyString(value)
        )
    override val healthCheckGracePeriod: Optional[Integer] =
      zio.aws.core.internal
        .optionalFromNullable(impl.healthCheckGracePeriod())
        .map(value => value: Integer)
    override val createdTime: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.createdTime())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val mixedInstancesPolicy: Optional[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.mixedInstancesPolicy())
      .map(value =>
        zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails
          .wrap(value)
      )
    override val availabilityZones: Optional[List[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.availabilityZones())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails
            .wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsAutoScalingAutoScalingGroupDetails
  ): zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupDetails.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-6.20.97.2-sources.jar: zio/aws/securityhub/model/AwsAutoScalingAutoScalingGroupDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.{Integer, NonEmptyString}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AwsAutoScalingAutoScalingGroupDetails(
    launchConfigurationName: Optional[NonEmptyString] = Optional.Absent,
    loadBalancerNames: Optional[Iterable[NonEmptyString]] = Optional.Absent,
    healthCheckType: Optional[NonEmptyString] = Optional.Absent,
    healthCheckGracePeriod: Optional[Integer] = Optional.Absent,
    createdTime: Optional[NonEmptyString] = Optional.Absent,
    mixedInstancesPolicy: Optional[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails
    ] = Optional.Absent,
    availabilityZones: Optional[Iterable[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails
    ]] = Optional.Absent,
    launchTemplate: Optional[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification
    ] = Optional.Absent,
    capacityRebalance: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsAutoScalingAutoScalingGroupDetails = {
    import AwsAutoScalingAutoScalingGroupDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsAutoScalingAutoScalingGroupDetails
      .builder()
      .optionallyWith(
        launchConfigurationName.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.launchConfigurationName)
      .optionallyWith(
        loadBalancerNames.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.loadBalancerNames)
      .optionallyWith(
        healthCheckType.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.healthCheckType)
      .optionallyWith(
        healthCheckGracePeriod.map(value => value: java.lang.Integer)
      )(_.healthCheckGracePeriod)
      .optionallyWith(
        createdTime.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.createdTime)
      .optionallyWith(mixedInstancesPolicy.map(value => value.buildAwsValue()))(
        _.mixedInstancesPolicy
      )
      .optionallyWith(
        availabilityZones.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.availabilityZones)
      .optionallyWith(launchTemplate.map(value => value.buildAwsValue()))(
        _.launchTemplate
      )
      .optionallyWith(capacityRebalance.map(value => value: java.lang.Boolean))(
        _.capacityRebalance
      )
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupDetails.ReadOnly =
    zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupDetails
      .wrap(buildAwsValue())
}
object AwsAutoScalingAutoScalingGroupDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsAutoScalingAutoScalingGroupDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupDetails =
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupDetails(
        launchConfigurationName.map(value => value),
        loadBalancerNames.map(value => value),
        healthCheckType.map(value => value),
        healthCheckGracePeriod.map(value => value),
        createdTime.map(value => value),
        mixedInstancesPolicy.map(value => value.asEditable),
        availabilityZones.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        launchTemplate.map(value => value.asEditable),
        capacityRebalance.map(value => value)
      )
    def launchConfigurationName: Optional[NonEmptyString]
    def loadBalancerNames: Optional[List[NonEmptyString]]
    def healthCheckType: Optional[NonEmptyString]
    def healthCheckGracePeriod: Optional[Integer]
    def createdTime: Optional[NonEmptyString]
    def mixedInstancesPolicy: Optional[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails.ReadOnly
    ]
    def availabilityZones: Optional[List[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails.ReadOnly
    ]]
    def launchTemplate: Optional[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification.ReadOnly
    ]
    def capacityRebalance: Optional[Boolean]
    def getLaunchConfigurationName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField(
        "launchConfigurationName",
        launchConfigurationName
      )
    def getLoadBalancerNames: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("loadBalancerNames", loadBalancerNames)
    def getHealthCheckType: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("healthCheckType", healthCheckType)
    def getHealthCheckGracePeriod: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("healthCheckGracePeriod", healthCheckGracePeriod)
    def getCreatedTime: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("createdTime", createdTime)
    def getMixedInstancesPolicy: ZIO[
      Any,
      AwsError,
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails.ReadOnly
    ] = AwsError.unwrapOptionField("mixedInstancesPolicy", mixedInstancesPolicy)
    def getAvailabilityZones: ZIO[Any, AwsError, List[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails.ReadOnly
    ]] = AwsError.unwrapOptionField("availabilityZones", availabilityZones)
    def getLaunchTemplate: ZIO[
      Any,
      AwsError,
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification.ReadOnly
    ] = AwsError.unwrapOptionField("launchTemplate", launchTemplate)
    def getCapacityRebalance: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("capacityRebalance", capacityRebalance)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsAutoScalingAutoScalingGroupDetails
  ) extends zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupDetails.ReadOnly {
    override val launchConfigurationName: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.launchConfigurationName())
        .map(value =>
          zio.aws.securityhub.model.primitives.NonEmptyString(value)
        )
    override val loadBalancerNames: Optional[List[NonEmptyString]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.loadBalancerNames())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.securityhub.model.primitives.NonEmptyString(item)
          }.toList
        )
    override val healthCheckType: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.healthCheckType())
        .map(value =>
          zio.aws.securityhub.model.primitives.NonEmptyString(value)
        )
    override val healthCheckGracePeriod: Optional[Integer] =
      zio.aws.core.internal
        .optionalFromNullable(impl.healthCheckGracePeriod())
        .map(value => value: Integer)
    override val createdTime: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.createdTime())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val mixedInstancesPolicy: Optional[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.mixedInstancesPolicy())
      .map(value =>
        zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails
          .wrap(value)
      )
    override val availabilityZones: Optional[List[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.availabilityZones())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails
            .wrap(item)
        }.toList
      )
    override val launchTemplate: Optional[
      zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.launchTemplate())
      .map(value =>
        zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification
          .wrap(value)
      )
    override val capacityRebalance: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.capacityRebalance())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsAutoScalingAutoScalingGroupDetails
  ): zio.aws.securityhub.model.AwsAutoScalingAutoScalingGroupDetails.ReadOnly =
    new Wrapper(impl)
}
